@@ -7,11 +7,13 @@ namespace phpDocumentor\Reflection\Assets;
 use phpDocumentor\Reflection\DocBlock\Tag;
 use phpDocumentor\Reflection\DocBlock\Tags\Formatter;
 use phpDocumentor\Reflection\FqsenResolver;
-use phpDocumentor\Reflection\DocBlock\Tags\Factory\StaticMethod;
 
-final class CustomParam implements Tag, StaticMethod
+final class CustomParam implements Tag
 {
+    /** @var string|null */
     public $myParam;
+
+    /** @var FqsenResolver|null */
     public $fqsenResolver;
 
     public function getName() : string
@@ -19,7 +21,7 @@ final class CustomParam implements Tag, StaticMethod
         return 'spy';
     }
 
-    public static function create($body, FqsenResolver $fqsenResolver = null, ?string $myParam = null)
+    public static function create(string $body, FqsenResolver $fqsenResolver = null, ?string $myParam = null)
     {
         $tag = new self();
         $tag->fqsenResolver = $fqsenResolver;
