@@ -9,8 +9,9 @@ use phpDocumentor\Reflection\DocBlock\Tags\Formatter;
 use phpDocumentor\Reflection\FqsenResolver;
 use phpDocumentor\Reflection\DocBlock\Tags\Factory\StaticMethod;
 
-final class CustomServiceInterface implements Tag, StaticMethod
+final class CustomServiceInterface implements Tag
 {
+    /** @var Formatter|null */
     public $formatter;
 
     public function getName() : string
@@ -18,7 +19,7 @@ final class CustomServiceInterface implements Tag, StaticMethod
         return 'spy';
     }
 
-    public static function create($body, Formatter $formatter = null)
+    public static function create(string $body, Formatter $formatter = null)
     {
         $tag = new self();
         $tag->formatter = $formatter;
